as.data.frame.entropyProfile: Coerce 'entropyProfile' to a Data Frame

View source: R/as.data.frame.entropyProfile.R

as.data.frame.entropyProfileR Documentation

Coerce entropyProfile to a Data Frame

Description

Function to extract summary information from an entropyProfile object. This function is internally used for plotting.

Usage

## S3 method for class 'entropyProfile'
as.data.frame(x, row.names = NULL, optional = FALSE, ...)

Arguments

x

An object of class entropyProfile.

row.names

Please see as.data.frame.

optional

Please see as.data.frame.

...

Additional arguments passed to the function.

Value

A data frame with tabular information on an entropy profile. This information includes the name of the proteins presenting mutations, the corresponding genomic positions, and the resulting entropies in the metagenome.


MetaEntropy documentation built on March 3, 2026, 5:08 p.m.