assessHotSpot: Evaluates Entropy Hotspot

View source: R/assessHotSpot.R

assessHotSpotR Documentation

Evaluates Entropy Hotspot

Description

Graphical and formal analyses of contiguous amino acids.

Usage

assessHotSpot(profile, boundaries, chartType = "boxplot")

Arguments

profile

An object of class entropyProfile.

boundaries

Numeric vector with the first and last genomic positions of the region to be evaluated. To be set interactively if not provided.

chartType

Chart type; either "boxplot", "stripchart" or "swarm".

Details

The query stretch (e.g. a protein domain with neutralizing epitopes) is compared against the full set of proteins. Hot spot boundaries should be indicated relative to the reference genome used in variant calling.

Value

htest object. This function is called primarily for its side effects.

See Also

getEntropySignature.

Examples

omicron <- getEntropySignature(wWater[wWater$wave == "third", ])

# Entrpy hotspot at SARS-CoV-2 receptor binding domain
assessHotSpot(omicron, c(22517, 23186), chartType = "swarm")


MetaEntropy documentation built on March 3, 2026, 5:08 p.m.