createStorage: Build a structure representing amino acid categories.

View source: R/createStorage.R

createStorageR Documentation

Build a structure representing amino acid categories.

Description

The function is used internally by fillPosition, which in turn is an auxiliary function of getEntropySignature. It creates a list with one element for each amino acid category, named according to the categories used (e.g., "aliphatic", "aromatic", etc.). Each element contains a set of amino acids identified by one-letter codes. The list also includes an element containing an empty numeric vector, whose names correspond to the labels of each category. This vector is to be populated with the frequency of each category at a given genomic position, by the fillPosition function.

Usage

createStorage(categories)

Arguments

categories

A character string. Similar to the categories parameter of getEntropySignature.

Value

A list with one element (character vector) for amino acid category and an element (empty named numeric vector) to be loaded with the frequency in the metagenome of each amino acid category.

See Also

getEntropySignature.


MetaEntropy documentation built on March 3, 2026, 5:08 p.m.