fillPosition: Translate amino acid frequencies into category frequencies

View source: R/fillPosition.R

fillPositionR Documentation

Translate amino acid frequencies into category frequencies

Description

The function is used internally by getEntropySignature. It creates a storage list by createStorage, and loads on it the frequency of each amino acid category based on the data contained in a data frame passed to the function (positionsSummary parameter).

Usage

fillPosition(positionSummary, categories)

Arguments

positionSummary

A data frame created by createPositionSummary.

categories

A character string indicating which category scheme to use. Similar to the categories parameter of getEntropySignature.

Value

A list with information on the frequencies of each amino acid category observed in a virome in a specific locus. The list contains a character vector for each amino acid category, and a named numeric vector containing the frequency of each category in the metagenome.

See Also

getEntropySignature.


MetaEntropy documentation built on March 3, 2026, 5:08 p.m.