getPosEntropy: Calculates aminoacidic entropy resulting from SNVs present in...

View source: R/getPosEntropy.R

getPosEntropyR Documentation

Calculates aminoacidic entropy resulting from SNVs present in a specific locus

Description

The function is used internally by getEntropySignature. It calculates Shannon entropy from categories and frequencies passed to the function.

Usage

getPosEntropy(variantPosition)

Arguments

variantPosition

A list, created and passed to the function by fillPosition. It contains information on the frequencies of each amino acid category observed in a virome, as a result of mutations at a given genomic position.

Value

A numeric value, corresponding to the entropy associated to the SNVs present at a specific locus.

See Also

getEntropySignature.


MetaEntropy documentation built on March 3, 2026, 5:08 p.m.