heatmap_entropyProfiles: Graphically compare entropy profiles

View source: R/heatMap_entropyProfiles.R

heatmap_entropyProfilesR Documentation

Graphically compare entropy profiles

Description

This function prints heatmaps of multiple entropy profiles (entropyProfile objects).

Usage

heatmap_entropyProfiles(..., keepInvariant = TRUE, showAllPeptides = TRUE)

Arguments

...

Unquoted entropyProfile data objects to be compared.

keepInvariant

Logical; whether to retain positions where entropy is zero. Defaults to FALSE.

showAllPeptides

Logical; whether the heatmap should show all peptides encoded by the virus, regardless of whether they have undergone mutations. Defaults to TRUE.

Value

A ggplot object representing the heatmap.

Examples

firstWave <- wWater[ wWater$wave == "first", ]
thirdWave <- wWater[ wWater$wave == "third", ]
# Filter out minor variants whose genotype matches that of the reference genome
firstWave <- firstWave[ firstWave$alt_aa_freq <= 0.97, ]
thirdWave <- thirdWave[ thirdWave$alt_aa_freq <= 0.97, ]
ancestral <- getEntropySignature(firstWave)
omicron <-  getEntropySignature(thirdWave)

# High entropies sustained over time in the spike protein, and signals
# compatible with pervasive negative selection in Omicron sublineages:
heatmap_entropyProfiles(ancestral, omicron)


MetaEntropy documentation built on Sept. 3, 2026, 5:10 p.m.