| mn908947.3 | R Documentation |
This type of data can be obtained from .gff (General Feature Format)
files using applications such as the rtracklayer package, or manually
from the corresponding entry in the GenBank database.
mn908947.3
An object of class list of length 2.
Nucleotide [Internet]. Bethesda (MD): National Library of Medicine (US), National Center for Biotechnology Information; [1988] – . Accession No. MN908947.3, Severe acute respiratory syndrome coronavirus 2 isolate Wuhan-Hu-1, complete genome. Available from: https://www.ncbi.nlm.nih.gov/nuccore/MN908947.3.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.