View source: R/as.data.frame.entropyProfile.R
| as.data.frame.entropyProfile | R Documentation |
entropyProfile to a Data FrameFunction to extract summary information from an entropyProfile
object. This function is internally used for plotting.
## S3 method for class 'entropyProfile'
as.data.frame(x, row.names = NULL, optional = FALSE, ...)
x |
An object of class |
row.names |
Please see |
optional |
Please see |
... |
Additional arguments passed to the function. |
A data frame with tabular information on an entropy profile.
This information includes the name of the proteins presenting
mutations, the corresponding genomic positions, and the resulting
entropies in the metagenome.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.