View source: R/assessHotSpot.R
| assessHotSpot | R Documentation |
Graphical and formal analyses of contiguous amino acids.
assessHotSpot(profile, boundaries, chartType = "boxplot")
profile |
An object of class |
boundaries |
Numeric vector with the first and last genomic positions of the region to be evaluated. To be set interactively if not provided. |
chartType |
Chart type; either "boxplot", "stripchart" or "swarm". |
The query stretch (e.g. a protein domain with neutralizing epitopes) is compared against the full set of proteins. Hot spot boundaries should be indicated relative to the reference genome used in variant calling.
htest object. This function is called primarily for its side
effects.
getEntropySignature.
omicron <- getEntropySignature(wWater[wWater$wave == "third", ])
# Entrpy hotspot at SARS-CoV-2 receptor binding domain
assessHotSpot(omicron, c(22517, 23186), chartType = "swarm")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.