View source: R/createPositionSummary.R
| createPositionSummary | R Documentation |
This function is used internally by getEntropySignature().
It creates a vector (aminoAcids) listing the amino acids
observed in a virome at a particular position under analysis, including the
reference amino acid, another vector (frequencies) with the
corresponding frequencies, and returns them combined in a data frame.
createPositionSummary(variants, ref_aa, alt_aa, alt_aa_freq)
variants |
A data frame, similar to the |
ref_aa |
Name of the column that carries reference amino acids. |
alt_aa |
Name of the column carrying alternative amino acids observed in the metagenome. |
alt_aa_freq |
Name of the column giving the frequencies of alternative amino acids. |
A data frame describing the variability (different amino
acids its frequencies) observed at a specific locus.
getEntropySignature.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.