View source: R/entropyProfile.R
| entropyProfile | R Documentation |
This function is intended primarily for internal use by
getEntropySignature.
entropyProfile(
polymorphisms,
position = "position",
linkage = "linkage",
ref = "ref",
alt = "alt",
protein = "protein",
aa_position = "aa_position",
ref_aa = "ref_aa",
alt_aa = "alt_aa",
alt_aa_freq = "alt_aa_freq",
entropies = NA_real_,
genome = mn908947.3
)
polymorphisms |
A data frame. Please see Details and Examples in
documentation for |
position |
Name of the |
linkage |
Information on linked positions. |
ref |
Column name with reference bases. |
alt |
Column name with the alternative bases observed in the metagenome. |
protein |
Name of the column carrying protein names. |
aa_position |
Name of the column that indicates the protein positions of the mutated amino acids. |
ref_aa |
Name of the column that carries the reference amino acids. |
alt_aa |
Name of the column carrying alternative amino acids observed in the metagenome. |
alt_aa_freq |
Name of the column giving the frequencies of alternative amino acids in the metagenome. |
entropies |
|
genome |
A list providing CDS data and length of the reference genome. |
The documentation for getEntropySignature details the type of
input needed to create a profile. entropyProfile uses the same parameters as
getEntropySignature, with the exception of categories and
entropies.
An (empty) object of class entropyProfile.
getEntropySignature.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.