| fillPosition | R Documentation |
The function is used internally by getEntropySignature.
It creates a storage list by createStorage, and loads on it the
frequency of each amino acid category based on the data contained in a data
frame passed to the function (positionsSummary parameter).
fillPosition(positionSummary, categories)
positionSummary |
A data frame created by |
categories |
A character string indicating which category scheme to
use. Similar to the |
A list with information on the frequencies of each amino acid
category observed in a virome in a specific locus. The list contains
a character vector for each amino acid category, and a named
numeric vector containing the frequency of each category in
the metagenome.
getEntropySignature.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.