View source: R/getPosEntropy.R
| getPosEntropy | R Documentation |
The function is used internally by getEntropySignature.
It calculates Shannon entropy from categories and frequencies passed to the
function.
getPosEntropy(variantPosition)
variantPosition |
A list, created and passed to the function by
|
A numeric value, corresponding to the entropy associated to
the SNVs present at a specific locus.
getEntropySignature.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.