View source: R/heatMap_entropyProfiles.R
| heatmap_entropyProfiles | R Documentation |
This function prints heatmaps of multiple entropy profiles
(entropyProfile objects).
heatmap_entropyProfiles(..., keepInvariant = TRUE, showAllPeptides = TRUE)
... |
Unquoted |
keepInvariant |
Logical; whether to retain positions where entropy is
zero. Defaults to |
showAllPeptides |
Logical; whether the heatmap should show all peptides
encoded by the virus, regardless of whether they have undergone mutations.
Defaults to |
A ggplot object representing the heatmap.
firstWave <- wWater[ wWater$wave == "first", ]
thirdWave <- wWater[ wWater$wave == "third", ]
# Filter out minor variants whose genotype matches that of the reference genome
firstWave <- firstWave[ firstWave$alt_aa_freq <= 0.97, ]
thirdWave <- thirdWave[ thirdWave$alt_aa_freq <= 0.97, ]
ancestral <- getEntropySignature(firstWave)
omicron <- getEntropySignature(thirdWave)
# High entropies sustained over time in the spike protein, and signals
# compatible with pervasive negative selection in Omicron sublineages:
heatmap_entropyProfiles(ancestral, omicron)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.